@@ -1,5 +1,5 @@
 eexp <-
 function (e, rate = 1, log.p = FALSE) 
 {
-    egamma(e, rate, 1, 1, log.p)
+    egamma(e, shape = 1, rate = rate, log.p = log.p)
 }
