@@ -58,6 +58,7 @@ function (formula, data = NULL, mstop = NA, expectiles = NA,
     helper <- list()
     for (k in 1:length(blsstr)) {
         values[[k]] = matrix(NA, nrow = m, ncol = np)
+        fitted = matrix(NA, nrow = m, ncol = np)
         helper[[k]] = NA
         if (types[[k]] == "bbs") {
             z[[k]] = values[[k]]
@@ -99,6 +100,7 @@ function (formula, data = NULL, mstop = NA, expectiles = NA,
             inb = inb[mstop(cvr)]
         }
         else print(paste("Quantile", pp[p], sep = " "))
+        fitted = fitted(inb)
         for (k in 1:length(blsstr)) {
             if (types[[k]] == "pspline") {
                 independent = which(dimnames(data)[[2]] == bls[[k]]$get_names())
@@ -171,21 +173,40 @@ function (formula, data = NULL, mstop = NA, expectiles = NA,
                 z[[k]] = values[[k]]
             }
         }
-        rm(inb)
         gc()
-        list(values, z)
+        list(values, z, fitted, inb)
     }
     coef.vector = myapply(1:np, function(i) dummy.reg(i, formula, 
         data, mstop, pp, cv10f, types, x, blsstr, bnd))
-    for (i in 1:np) for (k in 1:length(blsstr)) {
-        values[[k]][, i] = coef.vector[[i]][[1]][[k]]
-        if (types[[k]] == "2dspline") 
-            z[[k]][[i]] = coef.vector[[i]][[2]][[k]]
-        else z[[k]][, i] = coef.vector[[i]][[2]][[k]]
+    boost.object = list()
+    for (i in 1:np) {
+        boost.object[[i]] = coef.vector[[i]][[4]]
+        fitted[, i] = coef.vector[[i]][[3]]
+        for (k in 1:length(blsstr)) {
+            values[[k]][, i] = coef.vector[[i]][[1]][[k]]
+            if (types[[k]] == "2dspline") 
+                z[[k]][[i]] = coef.vector[[i]][[2]][[k]]
+            else z[[k]][, i] = coef.vector[[i]][[2]][[k]]
+        }
     }
     result = list(values = values, response = yy, covariates = x, 
         formula = formula, expectiles = pp, effects = types, 
-        helper = helper)
+        helper = helper, fitted = fitted)
+    result$predict <- function(newdata = NULL) {
+        values = list()
+        fitted = matrix(NA, nrow = nrow(newdata), ncol = np)
+        for (i in 1:np) {
+            fitted[, i] = predict(boost.object[[i]], newdata = newdata)
+        }
+        for (k in 1:length(blsstr)) {
+            values[[k]] = matrix(NA, nrow = nrow(newdata), ncol = np)
+            for (i in 1:np) {
+                values[[k]][, i] = predict(boost.object[[i]], 
+                  which = k, newdata = newdata) + boost.object[[i]]$offset
+            }
+        }
+        list(fitted = fitted, values = values)
+    }
     class(result) = c("expectreg", "boost")
     result
 }
